@@ -214,6 +214,9 @@ class OWWidget(QDialog, metaclass=WidgetMetaClass):
 
     savedWidgetGeometry = settings.Setting(None)
 
+    _node_item = None
+    _node      = None
+
     def __new__(cls, parent=None, *args, **kwargs):
         self = super().__new__(cls, None, cls.get_flags())
         QDialog.__init__(self, None, self.get_flags())
@@ -256,7 +259,11 @@ class OWWidget(QDialog, metaclass=WidgetMetaClass):
         """QDialog __init__ was already called in __new__,
         please do not call it here."""
 
-    def createdFromNode(self, node): self._node = node
+    def widgetNodeAdded(self, node_item):
+        if self._node_item is None: self._node_item = node_item
+
+    def createdFromNode(self, node):
+        if self._node is None: self._node = node
 
     @classmethod
     def get_flags(cls):
